@@ -5,10 +5,9 @@ from pynput.mouse import Button, Controller
 
 from pynput.keyboard import Listener, KeyCode
 
-
-
-def autoclick(start_stop_key_character,end_key_character):
-	delay = 0.01
+delay = 0.01
+def autoclick(start_stop_key_character,end_key_character,delay=0.01):
+	delay = delay
 	button = Button.left
 	start_stop_key = KeyCode(char=start_stop_key_character)
 	stop_key = KeyCode(char=end_key_character)
@@ -66,3 +65,4 @@ def autoclick(start_stop_key_character,end_key_character):
 	with Listener(on_press=on_press) as listener:
 		listener.join()
 
+
